@@ -6,10 +6,9 @@ use warnings;
 require 5.10.0;
 
 use version;
+our $VERSION = version->declare("v0.2.0");
 
 package code::UnifdefPlus;
-our $VERSION = version->declare("v0.4.0");
-
 use Storable qw(dclone);
 
 my $showErrs=1;
@@ -981,7 +980,7 @@ sub parseIf {
             my ($nextExpression, $wasSimplified) = $self->parseCondition($nextConditional);
 
             #my $nextExpression = $nextConditional;
-            if ( $wasSimplified && $nextExpression =~ /^($WS)$TRUE_PTRN($WS)$/ ) {
+            if ( $wasSimplified && $nextExpression =~ m/($WS)$TRUE_PTRN($WS)/ ) {
                 print $OUTFILE $EXPR->{$lang}->{LIT_ELSE} . "\n" if $self->shouldPrint($keep);
                 ( $nextExprType, $nextConditional ) = $self->parseLines($keep);
                 while ( !( $nextExprType =~ /$EXPR->{$lang}->{ENDIF}/s ) ) {
@@ -993,7 +992,7 @@ sub parseIf {
                     ( $nextExprType, $nextConditional ) = $self->parseLines(0);
                 }
             }
-            elsif ( $wasSimplified && $nextExpression =~ /^($WS)$FALSE_PTRN($WS)$/ ) {
+            elsif ( $wasSimplified && $nextExpression =~ /($WS)$FALSE_PTRN($WS)/ ) {
                 ( $nextExprType, $nextConditional ) = $self->parseLines(0);
             }
             else {
@@ -1017,6 +1016,7 @@ sub parseIf {
 			}
 			if ($elseConditional) {
 				my $rssElseCond;
+				# TBD, clean this up a bit -- do not run if not makefile...
 				($elseConditional, $elseCondition, $rssElseCond) = $self->makefileSimplifyIf($elseConditional, $elseCondition);
 				if ($elseCondition =~ /$TRUE_RESOLVED/) {
 	                print $OUTFILE $EXPR->{$lang}->{LIT_ELSE} . "\n" if $self->shouldPrint($keep);
@@ -1190,41 +1190,6 @@ sub parseLines {
 ## --------------------------------------------------------------------------
 ## MAKEFILE support:
 ##
-
-sub makefileSimplifyIfMacro {
-	my $self = shift;
-	my $prefix = shift;
-	my $paramsRef = shift;
-
-	my @params = @$paramsRef;
-	return if (scalar @params < 2) || (scalar @params > 3);
-	my $cond = $params[0]{simplified};
-	my $condRss = $params[0]{rss};
-	my $trueExpr = $params[1]{simplified};
-	my $trueRss = $params[1]{rss};
-	my $falseExpr; my $falseRss;
-	if (scalar @params == 3) {
-		$falseExpr = $params[2]{simplified};
-		$falseRss = $params[2]{rss};
-	} else {
-		$falseExpr = "";
-		$falseRss = RSS_UNCHANGED;
-	}
-	my $rss = max($condRss, $trueRss, $falseRss);
-	
-	$condRss = max($condRss, RSS_SIMPLIFIED) if ($cond =~ s/^\s++|\s++$//g);
-	
-	return ($trueExpr, max($rss,RSS_SIMPLIFIED)) if $self->isMakefileExprNonBlank($cond);
-	return ($falseExpr, max($rss,RSS_SIMPLIFIED)) if $self->isMakefileExprBlank($cond);
-	
-	my $rtStr;
-	$rtStr = "\$(".$prefix.$cond.",".$trueExpr.",".$falseExpr.")" if (scalar @params == 3);
-	$rtStr = "\$(".$prefix.$cond.",".$trueExpr.")" if (scalar @params == 2);
-
-	return ($rtStr, $rss);
-}
-
-
 sub makefileSimplifyOr {
 	my $self = shift;
 	my $prefix = shift;
@@ -1322,7 +1287,7 @@ my %makefileMacroSimplifiers = (
 	"or" =>         \&makefileSimplifyOr,
 	"and" =>        \&makefileSimplifyAnd,
 	"strip" => 	    \&makefileSimplifyStrip,
-	"if" =>         \&makefileSimplifyIfMacro,
+#	"if" => \&makefileSimplifyAnd,
 );
 
 
@@ -1330,7 +1295,6 @@ my %makefileMacroSimplifiers = (
 sub isMakefileExprNonBlank {
 	my $self=shift;
 	my $expr=shift;
-	return 1 if !defined $expr;
 	#tbd:  handle " $$"
 	if ($expr =~ /^(?:\$(?:(?:$PAREN_TOKEN)|(?:\w++)))*([^\$]++)/) {
 		return 1;
@@ -1530,11 +1494,8 @@ sub makefileSimplifyIf()
 	if($ifStmt =~ /^$EXPR->{$lang}->{IFDEF}|^$EXPR->{$lang}->{IFNDEF}/) {
 		#TBD: simplify expression?
 		my $negate = $ifStmt =~ /^$EXPR->{$lang}->{IFNDEF}/;
-		
-		# TBD: we should expand any of the known variables, but for now, just don't simplify...:
-		return ($ifStmt, $condition, RSS_UNCHANGED) if $condition =~ /\$/;
-		
 		my ($var) = $condition =~ /^(\w++)/;
+		die if !$var;
 		if ( $self->{defines}->{$var} ) {
 			$condition = $negate?$FALSE_RESOLVED:$TRUE_RESOLVED;
 			$rss = RSS_RESOLVED;
